/* =============================================================[ Display.hh ]=
 * Display.hh - print information on a display
 * Copyright (C) 2002 Hubert Chan <hubert@uhoreg.ca>
 *
 * ----------------------------------------------------------------( License )-
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * ------------------------------------------------------------( Description )-
 *
 * This file handles displaying player information to a display.
 *
 * ------------------------------------------------------------------------- */

#include <vector>

#include <alsaplayer/prefs.h>

#include "Display.hh"

extern "C" {
#include <xosd.h>
}

namespace {
  class XOSD_Display : public Display
  {
    xosd *osd;
    std::vector<std::vector<std::string> > screen_lines;
  public:
    XOSD_Display(SessionData &data)
      : Display(data,
		prefs_get_int(ap_prefs, "lirc", "display_width", 20),
		prefs_get_int(ap_prefs, "lirc", "display_height", 4)),
	screen_lines(NUM_MODES, std::vector<std::string>(height))
      {
	char *font = prefs_get_string(ap_prefs, "lirc", "osd_font", "fixed");
	char *colour = prefs_get_string(ap_prefs, "lirc", "osd_colour", "Red");
	//int timeout = prefs_get_int(ap_prefs, "lirc", "display_timeout", 3);
	char *position = prefs_get_string(ap_prefs, "lirc", "osd_pos", "bottom");
	xosd_pos pos = strcmp(position, "top") == 0 ? XOSD_top : XOSD_bottom;

	osd = xosd_init(font, colour, -1, pos, 0, 1, 4);
      }

    ~XOSD_Display()
      {
	xosd_uninit(osd);
      }

    void print(playermode_t mode, unsigned int line, const std::string &str)
      {
	screen_lines[mode][line] = str;
	if(mode == sessiondata.getMode())
	  xosd_display(osd, line, XOSD_string, str.c_str());
      }

    void modeChangedCallback()
      {
	for (unsigned int i = 0; i < height; i++)
	{
	  xosd_display(osd, i, XOSD_string, screen_lines[sessiondata.getMode()][i].c_str());
	}
      }
  };
}

Display *Display::create(SessionData &data)
{
  return new XOSD_Display(data);
}
