/* =========================================================[ SessionData.hh ]=
 * SessionData.hh - maintain information on the session
 * Copyright (C) 2002 Hubert Chan <hubert@uhoreg.ca>
 *
 * ----------------------------------------------------------------( License )-
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * ------------------------------------------------------------( Description )-
 *
 * This file maintains information on the current player session, and is used
 * to keep track of information common to all/most modules.
 *
 * ------------------------------------------------------------------------- */

#include "SessionData.hh"

ModeSubscriber::ModeSubscriber(SessionData &_sessiondata)
  : sessiondata(_sessiondata)
{
  callback_handle = sessiondata.registerModeCallback(this);
}

ModeSubscriber::~ModeSubscriber()
{
  sessiondata.unregisterModeCallback(callback_handle);
}

list<ModeSubscriber*>::iterator SessionData::registerModeCallback(ModeSubscriber* callback)
{
  mode_callbacks.push_front(callback);
  return mode_callbacks.begin();
}

void SessionData::unregisterModeCallback(list<ModeSubscriber*>::iterator &it)
{
  mode_callbacks.erase(it);
}

void SessionData::changeMode(playermode_t _mode)
{
  mode = _mode;
  for(list<ModeSubscriber*>::iterator i = mode_callbacks.begin();
      i != mode_callbacks.end(); ++i)
  {
    (*i)->modeChangedCallback();
  }
}

SessionData::SessionData(Playlist *_playlist)
  : mode(MODE_PLAYER),
    playlist(_playlist),
    coreplayer(playlist->GetCorePlayer()),
    display(Display::create(*this))
{}

SessionData::~SessionData()
{
  delete display;
}
