/* =========================================================[ SessionData.hh ]=
 * SessionData.hh - maintain information on the session
 * Copyright (C) 2002 Hubert Chan <hubert@uhoreg.ca>
 *
 * ----------------------------------------------------------------( License )-
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * ------------------------------------------------------------( Description )-
 *
 * This file maintains information on the current player session, and is used
 * to keep track of information common to all/most modules.
 *
 * ------------------------------------------------------------------------- */

#ifndef __SESSION_DATA_HH_
#define __SESSION_DATA_HH_

#include <list>

#include <alsaplayer/Playlist.h>
#include <alsaplayer/CorePlayer.h>

typedef enum { MODE_ALL = 0, MODE_PLAYER, MODE_PLAYLIST, MODE_MENU, NUM_MODES }
playermode_t;

class Display;

class SessionData;

class ModeSubscriber
{
  friend class SessionData;

  virtual void modeChangedCallback() = 0;

  list<ModeSubscriber*>::iterator callback_handle;
protected:
  SessionData &sessiondata;

  ModeSubscriber(SessionData &);
  virtual ~ModeSubscriber();
};

#include "Display.hh"

class SessionData
{
  friend class ModeSubscriber;

  playermode_t mode;
  list<ModeSubscriber*> mode_callbacks;
  list<ModeSubscriber*>::iterator registerModeCallback(ModeSubscriber *);
  void unregisterModeCallback(list<ModeSubscriber*>::iterator &);
public:
  SessionData(Playlist *);
  ~SessionData();

  Playlist *playlist;
  CorePlayer *coreplayer;
  Display *display;

  void changeMode(playermode_t);
  playermode_t getMode() const { return mode; }
};

#endif //__SESSION_DATA_HH_
